Module codec

Module codec 

Structs

MP3CodecData
Represents a bitfield.
MP3CodecDataBuilder
A builder for the bitfield.
MP3CodecType
mp3 specific SCI_HDAT0 and SCI_HDAT1 parsing optional enabled by using bitfield_struct feature
MP3CodecTypeBuilder
A builder for the bitfield.

Enums

Codec
see section 9.6.9 of VLSI datasheet contents of SCI_HDAT1 register depending on codec

Constants

MP3_BITRATE_MAPPING
see section 9.6.5 of VLSI datasheet
SCI_HDAT1_AAC
SCI_HDAT1_FLAC
SCI_HDAT1_M4A
SCI_HDAT1_MIDI
SCI_HDAT1_MP3_MAX
SCI_HDAT1_MP3_MIN
this is a min value - all >= is mp3
SCI_HDAT1_OGG
SCI_HDAT1_WAV
for all except mp3 SCI_HDAT0 contains the data rate measured in bytes per second To get the bitrate, multiply the value by 8
SCI_HDAT1_WMA

Functions

map_mp3_bitrate