Structs
- MP3Codec
Data - Represents a bitfield.
- MP3Codec
Data Builder - A builder for the bitfield.
- MP3Codec
Type - mp3 specific SCI_HDAT0 and SCI_HDAT1 parsing optional enabled by using bitfield_struct feature
- MP3Codec
Type Builder - A builder for the bitfield.
Enums
- Codec
- see section 9.6.9 of VLSI datasheet contents of SCI_HDAT1 register depending on codec
Constants
- MP3_
BITRATE_ MAPPING - see section 9.6.5 of VLSI datasheet
- SCI_
HDAT1_ AAC - SCI_
HDAT1_ FLAC - SCI_
HDAT1_ M4A - SCI_
HDAT1_ MIDI - SCI_
HDAT1_ MP3_ MAX - SCI_
HDAT1_ MP3_ MIN - this is a min value - all >= is mp3
- SCI_
HDAT1_ OGG - SCI_
HDAT1_ WAV - for all except mp3 SCI_HDAT0 contains the data rate measured in bytes per second To get the bitrate, multiply the value by 8
- SCI_
HDAT1_ WMA